# Copyright (c) 2002 Juri Pakaste
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

class ParsedSummary(object):
    __slots__ = ('title', 'link', 'description', 'last_build_date', 'contributors',
                 'managing_editor', 'web_master', 'language', 'items', 'copyright', 'creator')

    def __init__(self):
        self.items = []
        self.last_build_date = -1
        self.title = ""
        self.description = ""
        self.copyright = ""
        self.link = ""
        self.language = ""
        self.creator = ""
        self.contributors = list()

    def addItem(self, item):
        self.items.append(item)

